You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by iv...@apache.org on 2014/09/11 14:08:44 UTC

svn commit: r1624267 - /subversion/branches/1.8.x-r1589360/subversion/libsvn_diff/util.c

Author: ivan
Date: Thu Sep 11 12:08:43 2014
New Revision: 1624267

URL: http://svn.apache.org/r1624267
Log:
On '1.8.x-r1589360' branch: Use qsort() directly since svn_sort__array() is 
not available in 1.8.x.

* subversion/libsvn_diff/util.c
  (propchange_sort): Update docstring.
  (svn_diff__display_prop_diffs): Use qsort() instead of svn_sort__array().

Modified:
    subversion/branches/1.8.x-r1589360/subversion/libsvn_diff/util.c

Modified: subversion/branches/1.8.x-r1589360/subversion/libsvn_diff/util.c
URL: http://svn.apache.org/viewvc/subversion/branches/1.8.x-r1589360/subversion/libsvn_diff/util.c?rev=1624267&r1=1624266&r2=1624267&view=diff
==============================================================================
--- subversion/branches/1.8.x-r1589360/subversion/libsvn_diff/util.c (original)
+++ subversion/branches/1.8.x-r1589360/subversion/libsvn_diff/util.c Thu Sep 11 12:08:43 2014
@@ -487,7 +487,7 @@ display_mergeinfo_diff(const char *old_m
   return SVN_NO_ERROR;
 }
 
 /* svn_sort__array callback handling svn_prop_t by name */
 static int
 propchange_sort(const void *k1, const void *k2)
 {
@@ -510,7 +510,7 @@ svn_diff__display_prop_diffs(svn_stream_
   apr_array_header_t *changes = apr_array_copy(scratch_pool, propchanges);
   int i;
 
-  svn_sort__array(changes, propchange_sort);
+  qsort(changes->elts, changes->nelts, changes->elt_size, propchange_sort);
 
   for (i = 0; i < changes->nelts; i++)
     {
@@ -487,7 +487,7 @@ display_mergeinfo_diff(const char *old_m
 }
 
-/* svn_sort__array callback handling svn_prop_t by name */
+/* qsort callback handling svn_prop_t by name */
 static int
 propchange_sort(const void *k1, const void *k2)